
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....tensorflow.core.framework import cost_graph_pb2 as tensorflow_dot_core_dot_framework_dot_cost__graph__pb2
from ....tensorflow.core.framework import device_attributes_pb2 as tensorflow_dot_core_dot_framework_dot_device__attributes__pb2
from ....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
from ....tensorflow.core.framework import step_stats_pb2 as tensorflow_dot_core_dot_framework_dot_step__stats__pb2
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from ....tensorflow.core.protobuf import config_pb2 as tensorflow_dot_core_dot_protobuf_dot_config__pb2
from ....tensorflow.core.protobuf import debug_pb2 as tensorflow_dot_core_dot_protobuf_dot_debug__pb2
from ....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
from ....tensorflow.core.protobuf import named_tensor_pb2 as tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2
from ....tensorflow.core.protobuf import tensorflow_server_pb2 as tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/worker.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x0cWorkerProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/protobuf/worker.proto\x12\ntensorflow\x1a\x19google/protobuf/any.proto\x1a*tensorflow/core/framework/cost_graph.proto\x1a1tensorflow/core/framework/device_attributes.proto\x1a%tensorflow/core/framework/graph.proto\x1a*tensorflow/core/framework/step_stats.proto\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto\x1a%tensorflow/core/protobuf/config.proto\x1a$tensorflow/core/protobuf/debug.proto\x1a*tensorflow/core/protobuf/error_codes.proto\x1a+tensorflow/core/protobuf/named_tensor.proto\x1a0tensorflow/core/protobuf/tensorflow_server.proto"\x12\n\x10GetStatusRequest"L\n\x11GetStatusResponse\x127\n\x11device_attributes\x18\x01 \x03(\x0b2\x1c.tensorflow.DeviceAttributes"\xf0\x01\n\x1aCreateWorkerSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12)\n\nserver_def\x18\x02 \x01(\x0b2\x15.tensorflow.ServerDef\x12\x1d\n\x15isolate_session_state\x18\x03 \x01(\x08\x12?\n\x19cluster_device_attributes\x18\x04 \x03(\x0b2\x1c.tensorflow.DeviceAttributes\x12\x13\n\x0bmaster_task\x18\x05 \x01(\t\x12\x1a\n\x12master_incarnation\x18\x06 \x01(\x03"\x1d\n\x1bCreateWorkerSessionResponse"4\n\x1aDeleteWorkerSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t"\x1d\n\x1bDeleteWorkerSessionResponse"\xca\x02\n\x14RegisterGraphRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12$\n\x1ccreate_worker_session_called\x18\x06 \x01(\x08\x12\'\n\tgraph_def\x18\x02 \x01(\x0b2\x14.tensorflow.GraphDef\x12\x1c\n\x10has_control_flow\x18\x03 \x01(\x08B\x02\x18\x01\x12/\n\rgraph_options\x18\x04 \x01(\x0b2\x18.tensorflow.GraphOptions\x12/\n\rdebug_options\x18\x05 \x01(\x0b2\x18.tensorflow.DebugOptions\x12\x1c\n\x14collective_graph_key\x18\x07 \x01(\x03\x12-\n\x0cconfig_proto\x18\x08 \x01(\x0b2\x17.tensorflow.ConfigProto"-\n\x15RegisterGraphResponse\x12\x14\n\x0cgraph_handle\x18\x01 \x01(\t"l\n\x16DeregisterGraphRequest\x12\x16\n\x0esession_handle\x18\x02 \x01(\t\x12$\n\x1ccreate_worker_session_called\x18\x03 \x01(\x08\x12\x14\n\x0cgraph_handle\x18\x01 \x01(\t"\x19\n\x17DeregisterGraphResponse"&\n\x11CleanupAllRequest\x12\x11\n\tcontainer\x18\x01 \x03(\t"\x14\n\x12CleanupAllResponse"\x8a\x01\n\x0cExecutorOpts\x12\x14\n\x0crecord_costs\x18\x01 \x01(\x08\x12\x17\n\x0frecord_timeline\x18\x03 \x01(\x08\x12\x1f\n\x17record_partition_graphs\x18\x04 \x01(\x08\x12*\n"report_tensor_allocations_upon_oom\x18\x05 \x01(\x08"\xcd\x02\n\x0fRunGraphRequest\x12\x16\n\x0esession_handle\x18\x08 \x01(\t\x12$\n\x1ccreate_worker_session_called\x18\n \x01(\x08\x12\x14\n\x0cgraph_handle\x18\x01 \x01(\t\x12\x0f\n\x07step_id\x18\x02 \x01(\x03\x12+\n\texec_opts\x18\x05 \x01(\x0b2\x18.tensorflow.ExecutorOpts\x12*\n\x04send\x18\x03 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12\x10\n\x08recv_key\x18\x04 \x03(\t\x12\x12\n\nis_partial\x18\x06 \x01(\x08\x12\x1b\n\x13is_last_partial_run\x18\x07 \x01(\x08\x12%\n\x1dstore_errors_in_response_body\x18\t \x01(\x08\x12\x12\n\nrequest_id\x18\x0b \x01(\x03"\x91\x02\n\x10RunGraphResponse\x12*\n\x04recv\x18\x01 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12)\n\nstep_stats\x18\x02 \x01(\x0b2\x15.tensorflow.StepStats\x12,\n\ncost_graph\x18\x03 \x01(\x0b2\x18.tensorflow.CostGraphDef\x12-\n\x0fpartition_graph\x18\x04 \x03(\x0b2\x14.tensorflow.GraphDef\x12+\n\x0bstatus_code\x18\x05 \x01(\x0e2\x16.tensorflow.error.Code\x12\x1c\n\x14status_error_message\x18\x06 \x01(\t"&\n\x13CleanupGraphRequest\x12\x0f\n\x07step_id\x18\x01 \x01(\x03"\x16\n\x14CleanupGraphResponse"\xfb\x01\n\x11RecvTensorRequest\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x16\n\x0erendezvous_key\x18\x02 \x01(\t\x12\x0e\n\x06dma_ok\x18\x03 \x01(\x08\x123\n\x0fclient_locality\x18\x04 \x01(\x0b2\x1a.tensorflow.DeviceLocality\x123\n\x0fserver_locality\x18\x05 \x01(\x0b2\x1a.tensorflow.DeviceLocality\x12/\n\x11transport_options\x18\x06 \x01(\x0b2\x14.google.protobuf.Any\x12\x12\n\nrequest_id\x18\x07 \x01(\x03"\xaf\x01\n\x12RecvTensorResponse\x12\'\n\x06tensor\x18\x01 \x01(\x0b2\x17.tensorflow.TensorProto\x12\x0f\n\x07is_dead\x18\x02 \x01(\x08\x12\x19\n\x11send_start_micros\x18\x03 \x01(\x03\x12/\n\x11transport_options\x18\x04 \x01(\x0b2\x14.google.protobuf.Any\x12\x13\n\x0brequire_ack\x18\x05 \x01(\x08"-\n\x17MarkRecvFinishedRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x03"\x1a\n\x18MarkRecvFinishedResponse"o\n\x0eLoggingRequest\x12\x1a\n\x12enable_rpc_logging\x18\x01 \x01(\x08\x12\x1b\n\x13disable_rpc_logging\x18\x04 \x01(\x08\x12\r\n\x05clear\x18\x02 \x01(\x08\x12\x15\n\rfetch_step_id\x18\x03 \x03(\x03"N\n\x10LabeledStepStats\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12)\n\nstep_stats\x18\x02 \x01(\x0b2\x15.tensorflow.StepStats"=\n\x0fLoggingResponse\x12*\n\x04step\x18\x01 \x03(\x0b2\x1c.tensorflow.LabeledStepStats"\xab\x01\n\tTraceOpts\x12\x10\n\x08duration\x18\x01 \x01(\x01\x12\x19\n\x11use_step_profiler\x18\x02 \x01(\x08\x12\x1b\n\x13use_kernel_profiler\x18\x03 \x01(\x08\x12\x1d\n\x15use_extended_profiler\x18\x04 \x01(\x08\x12\x18\n\x10use_gpu_profiler\x18\x05 \x01(\x08\x12\x1b\n\x13use_sample_profiler\x18\x06 \x01(\x08"8\n\x0eTracingRequest\x12&\n\x07options\x18\x01 \x01(\x0b2\x15.tensorflow.TraceOpts"\x11\n\x0fTracingResponse"\xd1\x02\n\x0eRecvBufRequest\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x1a\n\x12buf_rendezvous_key\x18\x02 \x01(\t\x12\x11\n\tnum_bytes\x18\x03 \x01(\x03\x12\x0f\n\x07buf_ptr\x18\x04 \x01(\x06\x123\n\x0fclient_locality\x18\x05 \x01(\x0b2\x1a.tensorflow.DeviceLocality\x123\n\x0fserver_locality\x18\x06 \x01(\x0b2\x1a.tensorflow.DeviceLocality\x12/\n\x11transport_options\x18\x07 \x01(\x0b2\x14.google.protobuf.Any\x12\x12\n\nsrc_device\x18\x08 \x01(\t\x12\x12\n\ndst_device\x18\t \x01(\t\x12\x12\n\nrequest_id\x18\n \x01(\x03\x12\x17\n\x0fsrc_incarnation\x18\x0b \x01(\x04"\xa7\x01\n\x0fRecvBufResponse\x12\x0f\n\x07buf_ptr\x18\x01 \x01(\x06\x12\x11\n\tnum_bytes\x18\x02 \x01(\x03\x12\x0f\n\x07is_dead\x18\x03 \x01(\x08\x12/\n\x11transport_options\x18\x04 \x01(\x0b2\x14.google.protobuf.Any\x12\x19\n\x11send_start_micros\x18\x05 \x01(\x03\x12\x13\n\x0brequire_ack\x18\x06 \x01(\x08"\xaa\x01\n\x14CompleteGroupRequest\x12\x11\n\tgroup_key\x18\x01 \x01(\x05\x12\x12\n\ngroup_size\x18\x02 \x01(\x05\x12\x13\n\x0bdevice_type\x18\x03 \x01(\t\x12\x17\n\x0fcollective_type\x18\x05 \x01(\x05\x127\n\x11device_attributes\x18\x06 \x01(\x0b2\x1c.tensorflow.DeviceAttributesJ\x04\x08\x04\x10\x05"\xc5\x01\n\x15CompleteGroupResponse\x12\x11\n\tgroup_key\x18\x01 \x01(\x05\x12\x12\n\ngroup_size\x18\x02 \x01(\x05\x12\x13\n\x0bdevice_type\x18\x03 \x01(\t\x12\x11\n\tnum_tasks\x18\x04 \x01(\x05\x12\x18\n\x10communicator_key\x18\x07 \x01(\x0c\x127\n\x11device_attributes\x18\x08 \x03(\x0b2\x1c.tensorflow.DeviceAttributesJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07"\x97\x02\n\x17CompleteInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\'\n\tdata_type\x18\x03 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x04 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x11\n\tgroup_key\x18\x05 \x01(\x05\x12\x12\n\ngroup_size\x18\x06 \x01(\x05\x12\x14\n\x0cinstance_key\x18\x07 \x01(\x05\x12\x13\n\x0bdevice_type\x18\x08 \x01(\t\x12\x15\n\rsubdiv_offset\x18\t \x03(\x05\x12\x0e\n\x06device\x18\n \x01(\t\x12\x11\n\tis_source\x18\x0b \x01(\x08"K\n\x18CompleteInstanceResponse\x12\x14\n\x0cinstance_key\x18\x01 \x01(\x05\x12\x13\n\x0bsource_rank\x18\x02 \x01(\x05J\x04\x08\x03\x10\x04"+\n\x16GetStepSequenceRequest\x12\x11\n\tgraph_key\x18\x01 \x03(\x03"7\n\x0cStepSequence\x12\x11\n\tgraph_key\x18\x01 \x01(\x03\x12\x14\n\x0cnext_step_id\x18\x02 \x01(\x03"J\n\x17GetStepSequenceResponse\x12/\n\rstep_sequence\x18\x01 \x03(\x0b2\x18.tensorflow.StepSequenceB\x86\x01\n\x1aorg.tensorflow.distruntimeB\x0cWorkerProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_cost__graph__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_device__attributes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_step__stats__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_config__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_debug__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2.DESCRIPTOR])
_GETSTATUSREQUEST = _descriptor.Descriptor(name='GetStatusRequest', full_name='tensorflow.GetStatusRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=599, serialized_end=617)
_GETSTATUSRESPONSE = _descriptor.Descriptor(name='GetStatusResponse', full_name='tensorflow.GetStatusResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_attributes', full_name='tensorflow.GetStatusResponse.device_attributes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=619, serialized_end=695)
_CREATEWORKERSESSIONREQUEST = _descriptor.Descriptor(name='CreateWorkerSessionRequest', full_name='tensorflow.CreateWorkerSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.CreateWorkerSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='server_def', full_name='tensorflow.CreateWorkerSessionRequest.server_def', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='isolate_session_state', full_name='tensorflow.CreateWorkerSessionRequest.isolate_session_state', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cluster_device_attributes', full_name='tensorflow.CreateWorkerSessionRequest.cluster_device_attributes', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='master_task', full_name='tensorflow.CreateWorkerSessionRequest.master_task', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='master_incarnation', full_name='tensorflow.CreateWorkerSessionRequest.master_incarnation', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=698, serialized_end=938)
_CREATEWORKERSESSIONRESPONSE = _descriptor.Descriptor(name='CreateWorkerSessionResponse', full_name='tensorflow.CreateWorkerSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=940, serialized_end=969)
_DELETEWORKERSESSIONREQUEST = _descriptor.Descriptor(name='DeleteWorkerSessionRequest', full_name='tensorflow.DeleteWorkerSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.DeleteWorkerSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=971, serialized_end=1023)
_DELETEWORKERSESSIONRESPONSE = _descriptor.Descriptor(name='DeleteWorkerSessionResponse', full_name='tensorflow.DeleteWorkerSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1025, serialized_end=1054)
_REGISTERGRAPHREQUEST = _descriptor.Descriptor(name='RegisterGraphRequest', full_name='tensorflow.RegisterGraphRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RegisterGraphRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='create_worker_session_called', full_name='tensorflow.RegisterGraphRequest.create_worker_session_called', index=1, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.RegisterGraphRequest.graph_def', index=2, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='has_control_flow', full_name='tensorflow.RegisterGraphRequest.has_control_flow', index=3, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_options', full_name='tensorflow.RegisterGraphRequest.graph_options', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_options', full_name='tensorflow.RegisterGraphRequest.debug_options', index=5, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='collective_graph_key', full_name='tensorflow.RegisterGraphRequest.collective_graph_key', index=6, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='config_proto', full_name='tensorflow.RegisterGraphRequest.config_proto', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1057, serialized_end=1387)
_REGISTERGRAPHRESPONSE = _descriptor.Descriptor(name='RegisterGraphResponse', full_name='tensorflow.RegisterGraphResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_handle', full_name='tensorflow.RegisterGraphResponse.graph_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1389, serialized_end=1434)
_DEREGISTERGRAPHREQUEST = _descriptor.Descriptor(name='DeregisterGraphRequest', full_name='tensorflow.DeregisterGraphRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.DeregisterGraphRequest.session_handle', index=0, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='create_worker_session_called', full_name='tensorflow.DeregisterGraphRequest.create_worker_session_called', index=1, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_handle', full_name='tensorflow.DeregisterGraphRequest.graph_handle', index=2, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1436, serialized_end=1544)
_DEREGISTERGRAPHRESPONSE = _descriptor.Descriptor(name='DeregisterGraphResponse', full_name='tensorflow.DeregisterGraphResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1546, serialized_end=1571)
_CLEANUPALLREQUEST = _descriptor.Descriptor(name='CleanupAllRequest', full_name='tensorflow.CleanupAllRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='container', full_name='tensorflow.CleanupAllRequest.container', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1573, serialized_end=1611)
_CLEANUPALLRESPONSE = _descriptor.Descriptor(name='CleanupAllResponse', full_name='tensorflow.CleanupAllResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1613, serialized_end=1633)
_EXECUTOROPTS = _descriptor.Descriptor(name='ExecutorOpts', full_name='tensorflow.ExecutorOpts', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='record_costs', full_name='tensorflow.ExecutorOpts.record_costs', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='record_timeline', full_name='tensorflow.ExecutorOpts.record_timeline', index=1, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='record_partition_graphs', full_name='tensorflow.ExecutorOpts.record_partition_graphs', index=2, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='report_tensor_allocations_upon_oom', full_name='tensorflow.ExecutorOpts.report_tensor_allocations_upon_oom', index=3, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1636, serialized_end=1774)
_RUNGRAPHREQUEST = _descriptor.Descriptor(name='RunGraphRequest', full_name='tensorflow.RunGraphRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RunGraphRequest.session_handle', index=0, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='create_worker_session_called', full_name='tensorflow.RunGraphRequest.create_worker_session_called', index=1, number=10, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_handle', full_name='tensorflow.RunGraphRequest.graph_handle', index=2, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.RunGraphRequest.step_id', index=3, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exec_opts', full_name='tensorflow.RunGraphRequest.exec_opts', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send', full_name='tensorflow.RunGraphRequest.send', index=5, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recv_key', full_name='tensorflow.RunGraphRequest.recv_key', index=6, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_partial', full_name='tensorflow.RunGraphRequest.is_partial', index=7, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_last_partial_run', full_name='tensorflow.RunGraphRequest.is_last_partial_run', index=8, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='store_errors_in_response_body', full_name='tensorflow.RunGraphRequest.store_errors_in_response_body', index=9, number=9, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RunGraphRequest.request_id', index=10, number=11, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1777, serialized_end=2110)
_RUNGRAPHRESPONSE = _descriptor.Descriptor(name='RunGraphResponse', full_name='tensorflow.RunGraphResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='recv', full_name='tensorflow.RunGraphResponse.recv', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_stats', full_name='tensorflow.RunGraphResponse.step_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cost_graph', full_name='tensorflow.RunGraphResponse.cost_graph', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='partition_graph', full_name='tensorflow.RunGraphResponse.partition_graph', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_code', full_name='tensorflow.RunGraphResponse.status_code', index=4, number=5, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_error_message', full_name='tensorflow.RunGraphResponse.status_error_message', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2113, serialized_end=2386)
_CLEANUPGRAPHREQUEST = _descriptor.Descriptor(name='CleanupGraphRequest', full_name='tensorflow.CleanupGraphRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.CleanupGraphRequest.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2388, serialized_end=2426)
_CLEANUPGRAPHRESPONSE = _descriptor.Descriptor(name='CleanupGraphResponse', full_name='tensorflow.CleanupGraphResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2428, serialized_end=2450)
_RECVTENSORREQUEST = _descriptor.Descriptor(name='RecvTensorRequest', full_name='tensorflow.RecvTensorRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.RecvTensorRequest.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='rendezvous_key', full_name='tensorflow.RecvTensorRequest.rendezvous_key', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dma_ok', full_name='tensorflow.RecvTensorRequest.dma_ok', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='client_locality', full_name='tensorflow.RecvTensorRequest.client_locality', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='server_locality', full_name='tensorflow.RecvTensorRequest.server_locality', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transport_options', full_name='tensorflow.RecvTensorRequest.transport_options', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RecvTensorRequest.request_id', index=6, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2453, serialized_end=2704)
_RECVTENSORRESPONSE = _descriptor.Descriptor(name='RecvTensorResponse', full_name='tensorflow.RecvTensorResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.RecvTensorResponse.tensor', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_dead', full_name='tensorflow.RecvTensorResponse.is_dead', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send_start_micros', full_name='tensorflow.RecvTensorResponse.send_start_micros', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transport_options', full_name='tensorflow.RecvTensorResponse.transport_options', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='require_ack', full_name='tensorflow.RecvTensorResponse.require_ack', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2707, serialized_end=2882)
_MARKRECVFINISHEDREQUEST = _descriptor.Descriptor(name='MarkRecvFinishedRequest', full_name='tensorflow.MarkRecvFinishedRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.MarkRecvFinishedRequest.request_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2884, serialized_end=2929)
_MARKRECVFINISHEDRESPONSE = _descriptor.Descriptor(name='MarkRecvFinishedResponse', full_name='tensorflow.MarkRecvFinishedResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2931, serialized_end=2957)
_LOGGINGREQUEST = _descriptor.Descriptor(name='LoggingRequest', full_name='tensorflow.LoggingRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='enable_rpc_logging', full_name='tensorflow.LoggingRequest.enable_rpc_logging', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='disable_rpc_logging', full_name='tensorflow.LoggingRequest.disable_rpc_logging', index=1, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='clear', full_name='tensorflow.LoggingRequest.clear', index=2, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch_step_id', full_name='tensorflow.LoggingRequest.fetch_step_id', index=3, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2959, serialized_end=3070)
_LABELEDSTEPSTATS = _descriptor.Descriptor(name='LabeledStepStats', full_name='tensorflow.LabeledStepStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.LabeledStepStats.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_stats', full_name='tensorflow.LabeledStepStats.step_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3072, serialized_end=3150)
_LOGGINGRESPONSE = _descriptor.Descriptor(name='LoggingResponse', full_name='tensorflow.LoggingResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step', full_name='tensorflow.LoggingResponse.step', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3152, serialized_end=3213)
_TRACEOPTS = _descriptor.Descriptor(name='TraceOpts', full_name='tensorflow.TraceOpts', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='duration', full_name='tensorflow.TraceOpts.duration', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_step_profiler', full_name='tensorflow.TraceOpts.use_step_profiler', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_kernel_profiler', full_name='tensorflow.TraceOpts.use_kernel_profiler', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_extended_profiler', full_name='tensorflow.TraceOpts.use_extended_profiler', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_gpu_profiler', full_name='tensorflow.TraceOpts.use_gpu_profiler', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_sample_profiler', full_name='tensorflow.TraceOpts.use_sample_profiler', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3216, serialized_end=3387)
_TRACINGREQUEST = _descriptor.Descriptor(name='TracingRequest', full_name='tensorflow.TracingRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='options', full_name='tensorflow.TracingRequest.options', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3389, serialized_end=3445)
_TRACINGRESPONSE = _descriptor.Descriptor(name='TracingResponse', full_name='tensorflow.TracingResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3447, serialized_end=3464)
_RECVBUFREQUEST = _descriptor.Descriptor(name='RecvBufRequest', full_name='tensorflow.RecvBufRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.RecvBufRequest.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buf_rendezvous_key', full_name='tensorflow.RecvBufRequest.buf_rendezvous_key', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_bytes', full_name='tensorflow.RecvBufRequest.num_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buf_ptr', full_name='tensorflow.RecvBufRequest.buf_ptr', index=3, number=4, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='client_locality', full_name='tensorflow.RecvBufRequest.client_locality', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='server_locality', full_name='tensorflow.RecvBufRequest.server_locality', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transport_options', full_name='tensorflow.RecvBufRequest.transport_options', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='src_device', full_name='tensorflow.RecvBufRequest.src_device', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dst_device', full_name='tensorflow.RecvBufRequest.dst_device', index=8, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RecvBufRequest.request_id', index=9, number=10, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='src_incarnation', full_name='tensorflow.RecvBufRequest.src_incarnation', index=10, number=11, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3467, serialized_end=3804)
_RECVBUFRESPONSE = _descriptor.Descriptor(name='RecvBufResponse', full_name='tensorflow.RecvBufResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='buf_ptr', full_name='tensorflow.RecvBufResponse.buf_ptr', index=0, number=1, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_bytes', full_name='tensorflow.RecvBufResponse.num_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_dead', full_name='tensorflow.RecvBufResponse.is_dead', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transport_options', full_name='tensorflow.RecvBufResponse.transport_options', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='send_start_micros', full_name='tensorflow.RecvBufResponse.send_start_micros', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='require_ack', full_name='tensorflow.RecvBufResponse.require_ack', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3807, serialized_end=3974)
_COMPLETEGROUPREQUEST = _descriptor.Descriptor(name='CompleteGroupRequest', full_name='tensorflow.CompleteGroupRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='group_key', full_name='tensorflow.CompleteGroupRequest.group_key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='group_size', full_name='tensorflow.CompleteGroupRequest.group_size', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.CompleteGroupRequest.device_type', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='collective_type', full_name='tensorflow.CompleteGroupRequest.collective_type', index=3, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_attributes', full_name='tensorflow.CompleteGroupRequest.device_attributes', index=4, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=3977, serialized_end=4147)
_COMPLETEGROUPRESPONSE = _descriptor.Descriptor(name='CompleteGroupResponse', full_name='tensorflow.CompleteGroupResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='group_key', full_name='tensorflow.CompleteGroupResponse.group_key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='group_size', full_name='tensorflow.CompleteGroupResponse.group_size', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.CompleteGroupResponse.device_type', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_tasks', full_name='tensorflow.CompleteGroupResponse.num_tasks', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='communicator_key', full_name='tensorflow.CompleteGroupResponse.communicator_key', index=4, number=7, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_attributes', full_name='tensorflow.CompleteGroupResponse.device_attributes', index=5, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4150, serialized_end=4347)
_COMPLETEINSTANCEREQUEST = _descriptor.Descriptor(name='CompleteInstanceRequest', full_name='tensorflow.CompleteInstanceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.CompleteInstanceRequest.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.CompleteInstanceRequest.type', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_type', full_name='tensorflow.CompleteInstanceRequest.data_type', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.CompleteInstanceRequest.shape', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='group_key', full_name='tensorflow.CompleteInstanceRequest.group_key', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='group_size', full_name='tensorflow.CompleteInstanceRequest.group_size', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='instance_key', full_name='tensorflow.CompleteInstanceRequest.instance_key', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.CompleteInstanceRequest.device_type', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='subdiv_offset', full_name='tensorflow.CompleteInstanceRequest.subdiv_offset', index=8, number=9, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.CompleteInstanceRequest.device', index=9, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_source', full_name='tensorflow.CompleteInstanceRequest.is_source', index=10, number=11, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4350, serialized_end=4629)
_COMPLETEINSTANCERESPONSE = _descriptor.Descriptor(name='CompleteInstanceResponse', full_name='tensorflow.CompleteInstanceResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='instance_key', full_name='tensorflow.CompleteInstanceResponse.instance_key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='source_rank', full_name='tensorflow.CompleteInstanceResponse.source_rank', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4631, serialized_end=4706)
_GETSTEPSEQUENCEREQUEST = _descriptor.Descriptor(name='GetStepSequenceRequest', full_name='tensorflow.GetStepSequenceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_key', full_name='tensorflow.GetStepSequenceRequest.graph_key', index=0, number=1, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4708, serialized_end=4751)
_STEPSEQUENCE = _descriptor.Descriptor(name='StepSequence', full_name='tensorflow.StepSequence', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_key', full_name='tensorflow.StepSequence.graph_key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='next_step_id', full_name='tensorflow.StepSequence.next_step_id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4753, serialized_end=4808)
_GETSTEPSEQUENCERESPONSE = _descriptor.Descriptor(name='GetStepSequenceResponse', full_name='tensorflow.GetStepSequenceResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_sequence', full_name='tensorflow.GetStepSequenceResponse.step_sequence', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=4810, serialized_end=4884)
_GETSTATUSRESPONSE.fields_by_name['device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_CREATEWORKERSESSIONREQUEST.fields_by_name['server_def'].message_type = tensorflow_dot_core_dot_protobuf_dot_tensorflow__server__pb2._SERVERDEF
_CREATEWORKERSESSIONREQUEST.fields_by_name['cluster_device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_REGISTERGRAPHREQUEST.fields_by_name['graph_def'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_REGISTERGRAPHREQUEST.fields_by_name['graph_options'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._GRAPHOPTIONS
_REGISTERGRAPHREQUEST.fields_by_name['debug_options'].message_type = tensorflow_dot_core_dot_protobuf_dot_debug__pb2._DEBUGOPTIONS
_REGISTERGRAPHREQUEST.fields_by_name['config_proto'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._CONFIGPROTO
_RUNGRAPHREQUEST.fields_by_name['exec_opts'].message_type = _EXECUTOROPTS
_RUNGRAPHREQUEST.fields_by_name['send'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNGRAPHRESPONSE.fields_by_name['recv'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNGRAPHRESPONSE.fields_by_name['step_stats'].message_type = tensorflow_dot_core_dot_framework_dot_step__stats__pb2._STEPSTATS
_RUNGRAPHRESPONSE.fields_by_name['cost_graph'].message_type = tensorflow_dot_core_dot_framework_dot_cost__graph__pb2._COSTGRAPHDEF
_RUNGRAPHRESPONSE.fields_by_name['partition_graph'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_RUNGRAPHRESPONSE.fields_by_name['status_code'].enum_type = tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2._CODE
_RECVTENSORREQUEST.fields_by_name['client_locality'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICELOCALITY
_RECVTENSORREQUEST.fields_by_name['server_locality'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICELOCALITY
_RECVTENSORREQUEST.fields_by_name['transport_options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RECVTENSORRESPONSE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_RECVTENSORRESPONSE.fields_by_name['transport_options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LABELEDSTEPSTATS.fields_by_name['step_stats'].message_type = tensorflow_dot_core_dot_framework_dot_step__stats__pb2._STEPSTATS
_LOGGINGRESPONSE.fields_by_name['step'].message_type = _LABELEDSTEPSTATS
_TRACINGREQUEST.fields_by_name['options'].message_type = _TRACEOPTS
_RECVBUFREQUEST.fields_by_name['client_locality'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICELOCALITY
_RECVBUFREQUEST.fields_by_name['server_locality'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICELOCALITY
_RECVBUFREQUEST.fields_by_name['transport_options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RECVBUFRESPONSE.fields_by_name['transport_options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_COMPLETEGROUPREQUEST.fields_by_name['device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_COMPLETEGROUPRESPONSE.fields_by_name['device_attributes'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_COMPLETEINSTANCEREQUEST.fields_by_name['data_type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_COMPLETEINSTANCEREQUEST.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_GETSTEPSEQUENCERESPONSE.fields_by_name['step_sequence'].message_type = _STEPSEQUENCE
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetStatusResponse'] = _GETSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['CreateWorkerSessionRequest'] = _CREATEWORKERSESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateWorkerSessionResponse'] = _CREATEWORKERSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWorkerSessionRequest'] = _DELETEWORKERSESSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteWorkerSessionResponse'] = _DELETEWORKERSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['RegisterGraphRequest'] = _REGISTERGRAPHREQUEST
DESCRIPTOR.message_types_by_name['RegisterGraphResponse'] = _REGISTERGRAPHRESPONSE
DESCRIPTOR.message_types_by_name['DeregisterGraphRequest'] = _DEREGISTERGRAPHREQUEST
DESCRIPTOR.message_types_by_name['DeregisterGraphResponse'] = _DEREGISTERGRAPHRESPONSE
DESCRIPTOR.message_types_by_name['CleanupAllRequest'] = _CLEANUPALLREQUEST
DESCRIPTOR.message_types_by_name['CleanupAllResponse'] = _CLEANUPALLRESPONSE
DESCRIPTOR.message_types_by_name['ExecutorOpts'] = _EXECUTOROPTS
DESCRIPTOR.message_types_by_name['RunGraphRequest'] = _RUNGRAPHREQUEST
DESCRIPTOR.message_types_by_name['RunGraphResponse'] = _RUNGRAPHRESPONSE
DESCRIPTOR.message_types_by_name['CleanupGraphRequest'] = _CLEANUPGRAPHREQUEST
DESCRIPTOR.message_types_by_name['CleanupGraphResponse'] = _CLEANUPGRAPHRESPONSE
DESCRIPTOR.message_types_by_name['RecvTensorRequest'] = _RECVTENSORREQUEST
DESCRIPTOR.message_types_by_name['RecvTensorResponse'] = _RECVTENSORRESPONSE
DESCRIPTOR.message_types_by_name['MarkRecvFinishedRequest'] = _MARKRECVFINISHEDREQUEST
DESCRIPTOR.message_types_by_name['MarkRecvFinishedResponse'] = _MARKRECVFINISHEDRESPONSE
DESCRIPTOR.message_types_by_name['LoggingRequest'] = _LOGGINGREQUEST
DESCRIPTOR.message_types_by_name['LabeledStepStats'] = _LABELEDSTEPSTATS
DESCRIPTOR.message_types_by_name['LoggingResponse'] = _LOGGINGRESPONSE
DESCRIPTOR.message_types_by_name['TraceOpts'] = _TRACEOPTS
DESCRIPTOR.message_types_by_name['TracingRequest'] = _TRACINGREQUEST
DESCRIPTOR.message_types_by_name['TracingResponse'] = _TRACINGRESPONSE
DESCRIPTOR.message_types_by_name['RecvBufRequest'] = _RECVBUFREQUEST
DESCRIPTOR.message_types_by_name['RecvBufResponse'] = _RECVBUFRESPONSE
DESCRIPTOR.message_types_by_name['CompleteGroupRequest'] = _COMPLETEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CompleteGroupResponse'] = _COMPLETEGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CompleteInstanceRequest'] = _COMPLETEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CompleteInstanceResponse'] = _COMPLETEINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['GetStepSequenceRequest'] = _GETSTEPSEQUENCEREQUEST
DESCRIPTOR.message_types_by_name['StepSequence'] = _STEPSEQUENCE
DESCRIPTOR.message_types_by_name['GetStepSequenceResponse'] = _GETSTEPSEQUENCERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), {'DESCRIPTOR': _GETSTATUSREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(GetStatusRequest)
GetStatusResponse = _reflection.GeneratedProtocolMessageType('GetStatusResponse', (_message.Message,), {'DESCRIPTOR': _GETSTATUSRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(GetStatusResponse)
CreateWorkerSessionRequest = _reflection.GeneratedProtocolMessageType('CreateWorkerSessionRequest', (_message.Message,), {'DESCRIPTOR': _CREATEWORKERSESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CreateWorkerSessionRequest)
CreateWorkerSessionResponse = _reflection.GeneratedProtocolMessageType('CreateWorkerSessionResponse', (_message.Message,), {'DESCRIPTOR': _CREATEWORKERSESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CreateWorkerSessionResponse)
DeleteWorkerSessionRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkerSessionRequest', (_message.Message,), {'DESCRIPTOR': _DELETEWORKERSESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(DeleteWorkerSessionRequest)
DeleteWorkerSessionResponse = _reflection.GeneratedProtocolMessageType('DeleteWorkerSessionResponse', (_message.Message,), {'DESCRIPTOR': _DELETEWORKERSESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(DeleteWorkerSessionResponse)
RegisterGraphRequest = _reflection.GeneratedProtocolMessageType('RegisterGraphRequest', (_message.Message,), {'DESCRIPTOR': _REGISTERGRAPHREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RegisterGraphRequest)
RegisterGraphResponse = _reflection.GeneratedProtocolMessageType('RegisterGraphResponse', (_message.Message,), {'DESCRIPTOR': _REGISTERGRAPHRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RegisterGraphResponse)
DeregisterGraphRequest = _reflection.GeneratedProtocolMessageType('DeregisterGraphRequest', (_message.Message,), {'DESCRIPTOR': _DEREGISTERGRAPHREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(DeregisterGraphRequest)
DeregisterGraphResponse = _reflection.GeneratedProtocolMessageType('DeregisterGraphResponse', (_message.Message,), {'DESCRIPTOR': _DEREGISTERGRAPHRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(DeregisterGraphResponse)
CleanupAllRequest = _reflection.GeneratedProtocolMessageType('CleanupAllRequest', (_message.Message,), {'DESCRIPTOR': _CLEANUPALLREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CleanupAllRequest)
CleanupAllResponse = _reflection.GeneratedProtocolMessageType('CleanupAllResponse', (_message.Message,), {'DESCRIPTOR': _CLEANUPALLRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CleanupAllResponse)
ExecutorOpts = _reflection.GeneratedProtocolMessageType('ExecutorOpts', (_message.Message,), {'DESCRIPTOR': _EXECUTOROPTS, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(ExecutorOpts)
RunGraphRequest = _reflection.GeneratedProtocolMessageType('RunGraphRequest', (_message.Message,), {'DESCRIPTOR': _RUNGRAPHREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RunGraphRequest)
RunGraphResponse = _reflection.GeneratedProtocolMessageType('RunGraphResponse', (_message.Message,), {'DESCRIPTOR': _RUNGRAPHRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RunGraphResponse)
CleanupGraphRequest = _reflection.GeneratedProtocolMessageType('CleanupGraphRequest', (_message.Message,), {'DESCRIPTOR': _CLEANUPGRAPHREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CleanupGraphRequest)
CleanupGraphResponse = _reflection.GeneratedProtocolMessageType('CleanupGraphResponse', (_message.Message,), {'DESCRIPTOR': _CLEANUPGRAPHRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CleanupGraphResponse)
RecvTensorRequest = _reflection.GeneratedProtocolMessageType('RecvTensorRequest', (_message.Message,), {'DESCRIPTOR': _RECVTENSORREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RecvTensorRequest)
RecvTensorResponse = _reflection.GeneratedProtocolMessageType('RecvTensorResponse', (_message.Message,), {'DESCRIPTOR': _RECVTENSORRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RecvTensorResponse)
MarkRecvFinishedRequest = _reflection.GeneratedProtocolMessageType('MarkRecvFinishedRequest', (_message.Message,), {'DESCRIPTOR': _MARKRECVFINISHEDREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(MarkRecvFinishedRequest)
MarkRecvFinishedResponse = _reflection.GeneratedProtocolMessageType('MarkRecvFinishedResponse', (_message.Message,), {'DESCRIPTOR': _MARKRECVFINISHEDRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(MarkRecvFinishedResponse)
LoggingRequest = _reflection.GeneratedProtocolMessageType('LoggingRequest', (_message.Message,), {'DESCRIPTOR': _LOGGINGREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(LoggingRequest)
LabeledStepStats = _reflection.GeneratedProtocolMessageType('LabeledStepStats', (_message.Message,), {'DESCRIPTOR': _LABELEDSTEPSTATS, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(LabeledStepStats)
LoggingResponse = _reflection.GeneratedProtocolMessageType('LoggingResponse', (_message.Message,), {'DESCRIPTOR': _LOGGINGRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(LoggingResponse)
TraceOpts = _reflection.GeneratedProtocolMessageType('TraceOpts', (_message.Message,), {'DESCRIPTOR': _TRACEOPTS, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(TraceOpts)
TracingRequest = _reflection.GeneratedProtocolMessageType('TracingRequest', (_message.Message,), {'DESCRIPTOR': _TRACINGREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(TracingRequest)
TracingResponse = _reflection.GeneratedProtocolMessageType('TracingResponse', (_message.Message,), {'DESCRIPTOR': _TRACINGRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(TracingResponse)
RecvBufRequest = _reflection.GeneratedProtocolMessageType('RecvBufRequest', (_message.Message,), {'DESCRIPTOR': _RECVBUFREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RecvBufRequest)
RecvBufResponse = _reflection.GeneratedProtocolMessageType('RecvBufResponse', (_message.Message,), {'DESCRIPTOR': _RECVBUFRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(RecvBufResponse)
CompleteGroupRequest = _reflection.GeneratedProtocolMessageType('CompleteGroupRequest', (_message.Message,), {'DESCRIPTOR': _COMPLETEGROUPREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CompleteGroupRequest)
CompleteGroupResponse = _reflection.GeneratedProtocolMessageType('CompleteGroupResponse', (_message.Message,), {'DESCRIPTOR': _COMPLETEGROUPRESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CompleteGroupResponse)
CompleteInstanceRequest = _reflection.GeneratedProtocolMessageType('CompleteInstanceRequest', (_message.Message,), {'DESCRIPTOR': _COMPLETEINSTANCEREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CompleteInstanceRequest)
CompleteInstanceResponse = _reflection.GeneratedProtocolMessageType('CompleteInstanceResponse', (_message.Message,), {'DESCRIPTOR': _COMPLETEINSTANCERESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(CompleteInstanceResponse)
GetStepSequenceRequest = _reflection.GeneratedProtocolMessageType('GetStepSequenceRequest', (_message.Message,), {'DESCRIPTOR': _GETSTEPSEQUENCEREQUEST, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(GetStepSequenceRequest)
StepSequence = _reflection.GeneratedProtocolMessageType('StepSequence', (_message.Message,), {'DESCRIPTOR': _STEPSEQUENCE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(StepSequence)
GetStepSequenceResponse = _reflection.GeneratedProtocolMessageType('GetStepSequenceResponse', (_message.Message,), {'DESCRIPTOR': _GETSTEPSEQUENCERESPONSE, '__module__': 'tensorflow.core.protobuf.worker_pb2'})
_sym_db.RegisterMessage(GetStepSequenceResponse)
DESCRIPTOR._options = None
_REGISTERGRAPHREQUEST.fields_by_name['has_control_flow']._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/tpu/dynamic_padding.proto', package='tensorflow.tpu', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n2tensorflow/core/protobuf/tpu/dynamic_padding.proto\x12\x0etensorflow.tpu"O\n\nPaddingMap\x12\x11\n\targ_index\x18\x01 \x01(\x05\x12\x13\n\x0bshape_index\x18\x02 \x01(\x05\x12\x19\n\x11padding_arg_index\x18\x03 \x01(\x05B\x03\xf8\x01\x01b\x06proto3')
_PADDINGMAP = _descriptor.Descriptor(name='PaddingMap', full_name='tensorflow.tpu.PaddingMap', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='arg_index', full_name='tensorflow.tpu.PaddingMap.arg_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape_index', full_name='tensorflow.tpu.PaddingMap.shape_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_arg_index', full_name='tensorflow.tpu.PaddingMap.padding_arg_index', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=70, serialized_end=149)
DESCRIPTOR.message_types_by_name['PaddingMap'] = _PADDINGMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
PaddingMap = _reflection.GeneratedProtocolMessageType('PaddingMap', (_message.Message,), {'DESCRIPTOR': _PADDINGMAP, '__module__': 'tensorflow.core.protobuf.tpu.dynamic_padding_pb2'})
_sym_db.RegisterMessage(PaddingMap)
DESCRIPTOR._options = None
